@@ -1,8 +1,7 @@
 /**********************************************************************
- * $Id: export.h 2809 2009-12-06 01:05:24Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2009   Ragi Y. Burhum <ragi@burhum.com>
  *
@@ -12,7 +11,6 @@
  * See the COPYING file for more information.
  *
  **********************************************************************/
-
 #ifndef GEOS_EXPORT_H
 #define GEOS_EXPORT_H
 
@@ -30,5 +28,8 @@
 #  define GEOS_DLL
 #endif
 
-#endif // GEOS_EXPORT_H
+#endif
 
+#if defined(_MSC_VER)
+#  pragma warning(disable: 4251) // identifier : class type needs to have dll-interface to be used by clients of class type2
+#endif
