@@ -80,17 +80,16 @@ public:
      *
      * @return a clone of this instance
      */
-    std::unique_ptr<Geometry>
-    clone() const override
+    std::unique_ptr<Point> clone() const
     {
-        return std::unique_ptr<Geometry>(new Point(*this));
+        return std::unique_ptr<Point>(cloneImpl());
     }
 
     std::unique_ptr<CoordinateSequence> getCoordinates(void) const override;
 
     const CoordinateSequence* getCoordinatesRO() const;
 
-    size_t getNumPoints() const override;
+    std::size_t getNumPoints() const override;
     bool isEmpty() const override;
     bool isSimple() const override;
 
@@ -136,10 +135,9 @@ public:
         // a Point is always in normalized form
     }
 
-    std::unique_ptr<Geometry>
-    reverse() const override
+    std::unique_ptr<Point> reverse() const
     {
-        return clone();
+        return std::unique_ptr<Point>(reverseImpl());
     }
 
 protected:
@@ -162,6 +160,10 @@ protected:
 
     Point(const Point& p);
 
+    Point* cloneImpl() const override { return new Point(*this); }
+
+    Point* reverseImpl() const override { return new Point(*this); }
+
     Envelope::Ptr computeEnvelopeInternal() const override;
 
     int compareToSameClass(const Geometry* p) const override;
