@@ -42,7 +42,8 @@ namespace geos {
 namespace geomgraph { // geos::geomgraph
 namespace index { // geos::geomgraph::index
 
-
+/// \brief Computes the intersection of line segments, and adds the
+/// intersection to the edges containing the segments.
 class GEOS_DLL SegmentIntersector {
 
 private:
@@ -79,7 +80,7 @@ private:
     /// Elements are externally owned
     std::array<std::vector<Node*>*, 2> bdyNodes;
 
-    bool isTrivialIntersection(Edge* e0, size_t segIndex0, Edge* e1, size_t segIndex1);
+    bool isTrivialIntersection(Edge* e0, std::size_t segIndex0, Edge* e1, std::size_t segIndex1);
 
     bool isBoundaryPoint(algorithm::LineIntersector* li,
                          std::array<std::vector<Node*>*, 2>& tstBdyNodes);
@@ -89,7 +90,7 @@ private:
 
 public:
 
-    static bool isAdjacentSegments(size_t i1, size_t i2);
+    static bool isAdjacentSegments(std::size_t i1, std::size_t i2);
 
     // testing only
     int numTests;
@@ -111,7 +112,7 @@ public:
         includeProper(newIncludeProper),
         recordIsolated(newRecordIsolated),
         numIntersections(0),
-        bdyNodes{nullptr, nullptr},
+        bdyNodes{{nullptr, nullptr}},
         numTests(0)
     {}
 
@@ -129,7 +130,7 @@ public:
 
     bool hasProperInteriorIntersection();
 
-    void addIntersections(Edge* e0, size_t segIndex0, Edge* e1, size_t segIndex1);
+    void addIntersections(Edge* e0, std::size_t segIndex0, Edge* e1, std::size_t segIndex1);
 
     void setIsDoneIfProperInt(bool isDoneWhenProperInt);
 
