@@ -1,14 +1,13 @@
 /**********************************************************************
- * $Id: CLocalizer.h 3763 2013-02-01 06:34:23Z strk $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2008 Sean Gillies
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
  **********************************************************************
@@ -35,8 +34,7 @@ namespace io {
 /**
  * \class CLocalizer io.h geos.h
  */
-class GEOS_DLL CLocalizer
-{
+class GEOS_DLL CLocalizer {
 public:
 
     CLocalizer();
